unit FileTransformer;
//----------------------------------------------------------
//   TetraComponents
//   TextTransformer Support
//   Author: Dr. Detlef Meyer-Eltz
//   Many thanks to Dr. Hans-Peter Diettrich for his PASCAL advices
//   http://www.texttransformer.de
//   http://www.texttransformer.com
//   Meyer-Eltz@t-online.de
//
//   March, 2008
//----------------------------------------------------------

interface

uses
  Classes, SysUtils, ComCtrls, TetraDll, CustomTransformer, TetraMessage, TetraTypes;

type

TFileTransformer = class (TCustomTextTransformer)
private

public
  function TransformFile(const Source, Target: AnsiString;
    const ExtraParam: AnsiString = ''): boolean;
  function TransformToFile(Source: TStrings; const Target: AnsiString;
    const ExtraParam: AnsiString = ''): boolean;

published

  property EnableActions : BOOLEAN read m_bEnableActions write m_bEnableActions;
  property OnBeginDocument : TOnBeginDocument read FOnBeginDocument  write FOnBeginDocument;
  property OnEndDocument : TOnExit read FOnEndDocument  write FOnEndDocument;
  property OnFileError : TOnSourceTarget read FOnFileError write FOnFileError;
  property OnFileSuccess : TOnSourceTarget read FOnFileSuccess write FOnFileSuccess;
  property OnFileDone: TOnFileDone read FOnFileDone write FOnFileDone;

end;

//---------------------------------------------------------------------------

TTextFileN21Transformer = class (TFileTransformer)
private
  m_pSourceFiles : TStrings;
  m_asTargetFile : AnsiString;

  procedure SetSourceFiles(const Value: TStrings);
  procedure SetTargetFile(const Value: string);
public
  constructor Create(Owner : TComponent); override;
  destructor Destroy; override;

  function Execute(const xasExtraParam : AnsiString = '') : BOOLEAN; override;

published
  property SourceFiles : TStrings read m_pSourceFiles write SetSourceFiles;
  property TargetFile : AnsiString  read m_asTargetFile write SetTargetFile;
end;
//---------------------------------------------------------------------------

TTextFileN2NTransformer = class (TFileTransformer)
private

  m_pSourceFiles : TStrings;
  m_pTargetFiles : TStrings;

  procedure SetSourceFiles(const Value: TStrings);
  procedure SetTargetFiles(const Value: TStrings);

protected
public
  constructor Create(Owner : TComponent); override;
  destructor Destroy; override;

  function Execute(const xasExtraParam : AnsiString = '') : BOOLEAN; override;

published

  property SourceFiles : TStrings read m_pSourceFiles write SetSourceFiles;
  property TargetFiles : TStrings read m_pTargetFiles write SetTargetFiles;

end;

implementation


function TFileTransformer.TransformFile(const Source, Target: AnsiString;
  const ExtraParam: AnsiString = ''): boolean;
begin
  Result := inherited TransformFile(Source, Target, ExtraParam);
end;

function TFileTransformer.TransformToFile(Source: TStrings; const Target: AnsiString;
  const ExtraParam: AnsiString = ''): boolean;
begin
  Result := inherited TransformToFile(Source, Target, ExtraParam);
end;

{ TTextFileN21Transformer }

constructor TTextFileN21Transformer.Create(Owner : TComponent);
begin
  inherited Create(Owner);
   m_pSourceFiles := TStringList.Create;
   m_bContinue := true;
end;
//---------------------------------------------------------------------------
destructor TTextFileN21Transformer.Destroy();
begin
  FreeAndNil(m_pSourceFiles);
  inherited Destroy;
end;
//---------------------------------------------------------------------------
procedure TTextFileN21Transformer.SetSourceFiles(const Value: TStrings);
begin
  SourceFiles.Assign(Value);
  SetModified(true);
end;
//---------------------------------------------------------------------------
procedure TTextFileN21Transformer.SetTargetFile(const Value: string);
begin
  m_asTargetFile := Value;
  SetModified(true);
end;
//---------------------------------------------------------------------------
function TTextFileN21Transformer.Execute(const xasExtraParam : AnsiString) : BOOLEAN;
begin
 Result := TransformToFile(m_pSourceFiles, m_asTargetFile, xasExtraParam);
end;


{ TTextFileN2NTransformer }

constructor TTextFileN2NTransformer.Create(Owner : TComponent);
begin
  inherited Create(Owner);
   m_pSourceFiles := TStringList.Create;
   m_pTargetFiles := TStringList.Create;
   m_bContinue := true;
end;
//---------------------------------------------------------------------------
destructor TTextFileN2NTransformer.Destroy();
begin
  FreeAndNil(m_pSourceFiles);
  FreeAndNil(m_pTargetFiles);
  inherited Destroy;
end;
//---------------------------------------------------------------------------
procedure TTextFileN2NTransformer.SetSourceFiles(const Value: TStrings);
begin
  SourceFiles.Assign(Value);
  SetModified(true);
end;
//---------------------------------------------------------------------------
procedure TTextFileN2NTransformer.SetTargetFiles(const Value: TStrings);
begin
  TargetFiles.Assign(Value);
  SetModified(true);
end;
//---------------------------------------------------------------------------
function TTextFileN2NTransformer.Execute(const xasExtraParam : AnsiString) : BOOLEAN;
begin
  Result := TransformToFiles(m_pSourceFiles, m_pTargetFiles, xasExtraParam);
end;

end.
