unit MemoTransformer;
//----------------------------------------------------------
//   TetraComponents
//   TextTransformer Support
//   Author: Dr. Detlef Meyer-Eltz
//   Many thanks to Dr. Hans-Peter Diettrich for his PASCAL advices
//   http://www.texttransformer.de
//   http://www.texttransformer.com
//   Meyer-Eltz@t-online.de
//
//   March, 2008
//----------------------------------------------------------

interface

uses
  Classes, SysUtils, ComCtrls, StdCtrls, TetraDll, CustomTransformer, StringTransformer, TetraMessage, TetraTypes;

type


TMemoTextTransformer = class (TCustomTextTransformer)
private
  m_InputMemo: TCustomMemo;
  m_OutputMemo : TCustomMemo;

protected
//  procedure Notification(AComponent: TComponent; Operation: TOperation); override;
  function CheckMemosExists(): BOOLEAN;
  procedure SetInputMemo(const Value : TCustomMemo);
  procedure SetOutputMemo(const Value : TCustomMemo);

public
  constructor Create(Owner : TComponent); override;

  function Execute(const xasExtraParam : AnsiString = '') : BOOLEAN; override;

published
  property Input : TCustomMemo read m_InputMemo write SetInputMemo;
  property Output : TCustomMemo read m_OutputMemo write SetOutputMemo;
end;

implementation

//---------------------------------------------------------------------------
constructor TMemoTextTransformer.Create(Owner : TComponent);
begin
  inherited Create(Owner);
  m_InputMemo := NIL;
  m_OutputMemo := NIL;
end;
//---------------------------------------------------------------------------
procedure TMemoTextTransformer.SetInputMemo(const Value : TCustomMemo);
begin
  if Assigned(m_InputMemo) then
    m_InputMemo.RemoveFreeNotification(Self);

  m_InputMemo := Value;

  if Assigned(m_InputMemo) then
    m_InputMemo.FreeNotification(Self)
   else
    Stop();

end;
//---------------------------------------------------------------------------
procedure TMemoTextTransformer.SetOutputMemo(const Value : TCustomMemo);
begin
  if Assigned(m_OutputMemo) then
    m_OutputMemo.RemoveFreeNotification(Self);

  m_OutputMemo := Value;

  if Assigned(m_OutputMemo) then
    m_OutputMemo.FreeNotification(Self)
   else
    Stop();

end;
//---------------------------------------------------------------------------
function TMemoTextTransformer.CheckMemosExists(): BOOLEAN;
begin
  result := true;
  if not Assigned(m_InputMemo) then
     result := false;
  if not Assigned(m_OutputMemo) then
     result := false;
end;
(* BDS 2007 hangs when closing a project with this function
//---------------------------------------------------------------------------
procedure TMemoTextTransformer.Notification(AComponent : TComponent;
  Operation : TOperation);
begin
  if Operation = opRemove then begin
    if AComponent = m_InputMemo then
       m_InputMemo := Nil
    else
    if AComponent = m_OutputMemo then
       m_OutputMemo := Nil;
  end;
end;
*)
//---------------------------------------------------------------------------
function TMemoTextTransformer.Execute(const xasExtraParam : AnsiString) : BOOLEAN;
begin
  if CheckMemosExists() and SetActive() then begin
    ClearMessages();
    m_sExtra := xasExtraParam;
    m_OutputMemo.Lines.Text := AdjustLineBreaks(_TetraDll._TransformTextToText(PAnsiChar(m_InputMemo.Lines.Text), PAnsiChar(xasExtraParam)));
    SetModified(false);
  end;  //else OnException or OnParserMessage

  result := not HasError();
end;

end.